"""
Python module generated from Java source file java.util.function.BiConsumer

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Objects
from java.util.function import *
from typing import Any, Callable, Iterable, Tuple


class BiConsumer:
    """
    Represents an operation that accepts two input arguments and returns no
    result.  This is the two-arity specialization of Consumer.
    Unlike most other functional interfaces, `BiConsumer` is expected
    to operate via side-effects.
    
    This is a <a href="package-summary.html">functional interface</a>
    whose functional method is .accept(Object, Object).
    
    Type `<T>`: the type of the first argument to the operation
    
    Type `<U>`: the type of the second argument to the operation

    See
    - Consumer

    Since
    - 1.8
    """

    def accept(self, t: "T", u: "U") -> None:
        """
        Performs this operation on the given arguments.

        Arguments
        - t: the first input argument
        - u: the second input argument
        """
        ...


    def andThen(self, after: "BiConsumer"["T", "U"]) -> "BiConsumer"["T", "U"]:
        """
        Returns a composed `BiConsumer` that performs, in sequence, this
        operation followed by the `after` operation. If performing either
        operation throws an exception, it is relayed to the caller of the
        composed operation.  If performing this operation throws an exception,
        the `after` operation will not be performed.

        Arguments
        - after: the operation to perform after this operation

        Returns
        - a composed `BiConsumer` that performs in sequence this
        operation followed by the `after` operation

        Raises
        - NullPointerException: if `after` is null
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.server.PluginEnableEvent

Java source file obtained from artifact spigot-api version 1.21.2-R0.1-20241023.084343-5

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.event import HandlerList
from org.bukkit.event.server import *
from org.bukkit.plugin import Plugin
from typing import Any, Callable, Iterable, Tuple


class PluginEnableEvent(PluginEvent):
    """
    Called when a plugin is enabled.
    """

    def __init__(self, plugin: "Plugin"):
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.EnchantingTable

Java source file obtained from artifact spigot-api version 1.21.2-R0.1-20241023.084343-5

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Nameable
from org.bukkit.block import *
from typing import Any, Callable, Iterable, Tuple


class EnchantingTable(TileState, Nameable):
    """
    Represents a captured state of an enchanting table.
    """





"""
Python module generated from Java source file org.bukkit.material.FlowerPot

Java source file obtained from artifact spigot-api version 1.21.2-R0.1-20241023.084343-5

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import GrassSpecies
from org.bukkit import Material
from org.bukkit import TreeSpecies
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class FlowerPot(MaterialData):
    """
    Represents a flower pot.

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        """
        Default constructor for a flower pot.
        """
        ...


    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def getContents(self) -> "MaterialData":
        """
        Get the material in the flower pot

        Returns
        - material MaterialData for the block currently in the flower pot
            or null if empty
        """
        ...


    def setContents(self, materialData: "MaterialData") -> None:
        """
        Set the contents of the flower pot

        Arguments
        - materialData: MaterialData of the block to put in the flower pot.
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "FlowerPot":
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerVelocityEvent

Java source file obtained from artifact spigot-api version 1.21.2-R0.1-20241023.084343-5

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class PlayerVelocityEvent(PlayerEvent, Cancellable):
    """
    Called when the velocity of a player changes.
    """

    def __init__(self, player: "Player", velocity: "Vector"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getVelocity(self) -> "Vector":
        """
        Gets the velocity vector that will be sent to the player

        Returns
        - Vector the player will get
        """
        ...


    def setVelocity(self, velocity: "Vector") -> None:
        """
        Sets the velocity vector in meters per tick that will be sent to the player

        Arguments
        - velocity: The velocity vector that will be sent to the player
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.event.block.VaultDisplayItemEvent

Java source file obtained from artifact spigot-api version 1.21.2-R0.1-20241023.084343-5

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class VaultDisplayItemEvent(BlockEvent, Cancellable):
    """
    Called when a vault in a trial chamber is about to display an item.
    """

    def __init__(self, theBlock: "Block", displayItem: "ItemStack"):
        ...


    def getDisplayItem(self) -> "ItemStack":
        """
        Gets the item that will be displayed inside the vault.

        Returns
        - the item to be displayed
        """
        ...


    def setDisplayItem(self, displayItem: "ItemStack") -> None:
        """
        Sets the item that will be displayed inside the vault.

        Arguments
        - displayItem: the item to be displayed
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancelled: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityToggleSwimEvent

Java source file obtained from artifact spigot-api version 1.21.2-R0.1-20241023.084343-5

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import LivingEntity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityToggleSwimEvent(EntityEvent, Cancellable):
    """
    Sent when an entity's swimming status is toggled.
    """

    def __init__(self, who: "LivingEntity", isSwimming: bool):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def isSwimming(self) -> bool:
        """
        Returns True if the entity is now swims or
        False if the entity stops swimming.

        Returns
        - new swimming state
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.graph.GraphConstants

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.graph import *
from typing import Any, Callable, Iterable, Tuple


class GraphConstants:
    """
    A utility class to hold various constants used by the Guava Graph library.
    """





"""
Python module generated from Java source file org.bukkit.attribute.Attribute

Java source file obtained from artifact spigot-api version 1.21.2-R0.1-20241023.084343-5

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import Bukkit
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit import Translatable
from org.bukkit.attribute import *
from typing import Any, Callable, Iterable, Tuple


class Attribute(Enum):
    """
    Types of attributes which may be present on an Attributable.
    """

    GENERIC_MAX_HEALTH = ("max_health")
    """
    Maximum health of an Entity.
    """
    GENERIC_FOLLOW_RANGE = ("follow_range")
    """
    Range at which an Entity will follow others.
    """
    GENERIC_KNOCKBACK_RESISTANCE = ("knockback_resistance")
    """
    Resistance of an Entity to knockback.
    """
    GENERIC_MOVEMENT_SPEED = ("movement_speed")
    """
    Movement speed of an Entity.
    """
    GENERIC_FLYING_SPEED = ("flying_speed")
    """
    Flying speed of an Entity.
    """
    GENERIC_ATTACK_DAMAGE = ("attack_damage")
    """
    Attack damage of an Entity.
    """
    GENERIC_ATTACK_KNOCKBACK = ("attack_knockback")
    """
    Attack knockback of an Entity.
    """
    GENERIC_ATTACK_SPEED = ("attack_speed")
    """
    Attack speed of an Entity.
    """
    GENERIC_ARMOR = ("armor")
    """
    Armor bonus of an Entity.
    """
    GENERIC_ARMOR_TOUGHNESS = ("armor_toughness")
    """
    Armor durability bonus of an Entity.
    """
    GENERIC_FALL_DAMAGE_MULTIPLIER = ("fall_damage_multiplier")
    """
    The fall damage multiplier of an Entity.
    """
    GENERIC_LUCK = ("luck")
    """
    Luck bonus of an Entity.
    """
    GENERIC_MAX_ABSORPTION = ("max_absorption")
    """
    Maximum absorption of an Entity.
    """
    GENERIC_SAFE_FALL_DISTANCE = ("safe_fall_distance")
    """
    The distance which an Entity can fall without damage.
    """
    GENERIC_SCALE = ("scale")
    """
    The relative scale of an Entity.
    """
    GENERIC_STEP_HEIGHT = ("step_height")
    """
    The height which an Entity can walk over.
    """
    GENERIC_GRAVITY = ("gravity")
    """
    The gravity applied to an Entity.
    """
    GENERIC_JUMP_STRENGTH = ("jump_strength")
    """
    Strength with which an Entity will jump.
    """
    GENERIC_BURNING_TIME = ("burning_time")
    """
    How long an entity remains burning after ingition.
    """
    GENERIC_EXPLOSION_KNOCKBACK_RESISTANCE = ("explosion_knockback_resistance")
    """
    Resistance to knockback from explosions.
    """
    GENERIC_MOVEMENT_EFFICIENCY = ("movement_efficiency")
    """
    Movement speed through difficult terrain.
    """
    GENERIC_OXYGEN_BONUS = ("oxygen_bonus")
    """
    Oxygen use underwater.
    """
    GENERIC_WATER_MOVEMENT_EFFICIENCY = ("water_movement_efficiency")
    """
    Movement speed through water.
    """
    GENERIC_TEMPT_RANGE = ("tempt_range")
    """
    Range at which mobs will be tempted by items.
    """
    PLAYER_BLOCK_INTERACTION_RANGE = ("block_interaction_range")
    """
    The block reach distance of a Player.
    """
    PLAYER_ENTITY_INTERACTION_RANGE = ("entity_interaction_range")
    """
    The entity reach distance of a Player.
    """
    PLAYER_BLOCK_BREAK_SPEED = ("block_break_speed")
    """
    Block break speed of a Player.
    """
    PLAYER_MINING_EFFICIENCY = ("mining_efficiency")
    """
    Mining speed for correct tools.
    """
    PLAYER_SNEAKING_SPEED = ("sneaking_speed")
    """
    Sneaking speed.
    """
    PLAYER_SUBMERGED_MINING_SPEED = ("submerged_mining_speed")
    """
    Underwater mining speed.
    """
    PLAYER_SWEEPING_DAMAGE_RATIO = ("sweeping_damage_ratio")
    """
    Sweeping damage.
    """
    ZOMBIE_SPAWN_REINFORCEMENTS = ("spawn_reinforcements")
    """
    Chance of a zombie to spawn reinforcements.
    """


    def getKey(self) -> "NamespacedKey":
        ...


    def getTranslationKey(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.event.block.BlockFadeEvent

Java source file obtained from artifact spigot-api version 1.21.2-R0.1-20241023.084343-5

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.block import BlockState
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockFadeEvent(BlockEvent, Cancellable):
    """
    Called when a block fades, melts or disappears based on world conditions
    
    Examples:
    
    - Snow melting due to being near a light source.
    - Ice melting due to being near a light source.
    - Fire burning out after time, without destroying fuel block.
    - Coral fading to dead coral due to lack of water
    - Turtle Egg bursting when a turtle hatches
    
    
    If a Block Fade event is cancelled, the block will not fade, melt or
    disappear.
    """

    def __init__(self, block: "Block", newState: "BlockState"):
        ...


    def getNewState(self) -> "BlockState":
        """
        Gets the state of the block that will be fading, melting or
        disappearing.

        Returns
        - The block state of the block that will be fading, melting or
            disappearing
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.CreakingHeart

Java source file obtained from artifact spigot-api version 1.21.2-R0.1-20241023.084343-5

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import MinecraftExperimental
from org.bukkit.block.data import Orientable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class CreakingHeart(Orientable):
    """
    'creaking' is the creaking status of this block.
    """

    def getCreaking(self) -> "Creaking":
        """
        Gets the value of the 'creaking' property.

        Returns
        - the 'creaking' value
        """
        ...


    def setCreaking(self, creaking: "Creaking") -> None:
        """
        Sets the value of the 'creaking' property.

        Arguments
        - creaking: the new 'creaking' value
        """
        ...


    class Creaking(Enum):
        """
        Creaking status.
        """

        DISABLED = 0
        """
        The block is disabled.
        """
        DORMANT = 1
        """
        The block is dormant.
        """
        ACTIVE = 2
        """
        The block is active.
        """
